@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.7.") or
-    raise "ruby lib version (2.7.1) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.7.3) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.7/mips64el-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "7"
-  CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "83"
-  CONFIG["INSTALL"] = '/home/pea/pobj/ruby-2.7.1/bin/install -c'
+  CONFIG["TEENY"] = "3"
+  CONFIG["PATCHLEVEL"] = "183"
+  CONFIG["INSTALL"] = '/home/pea/pobj/ruby-2.7.3/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)27"
@@ -94,8 +94,8 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
-  CONFIG["strict_warnflags"] = ""
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable"
+  CONFIG["strict_warnflags"] = "-std=gnu99"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
@@ -149,9 +149,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/home/pea/pobj/ruby-2.7.1/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/home/pea/pobj/ruby-2.7.1/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/home/pea/pobj/ruby-2.7.1/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/home/pea/pobj/ruby-2.7.3/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/home/pea/pobj/ruby-2.7.3/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/home/pea/pobj/ruby-2.7.3/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -165,9 +165,9 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "cc (GCC) 4.2.1 20070719 \nCopyright (C) 2007 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 10.0.1 \nTarget: mips64el-unknown-openbsd6.9\nThread model: posix\nInstalledDir: /usr/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "/usr/bin/cc -std=gnu99"
+  CONFIG["MJIT_CC"] = "/usr/bin/cc"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
@@ -184,22 +184,22 @@ module RbConfig
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -fstack-protector-strong -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
-  CONFIG["CC"] = "cc -std=gnu99"
-  CONFIG["target_os"] = "openbsd6.7"
+  CONFIG["CC"] = "cc"
+  CONFIG["target_os"] = "openbsd6.9"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "mips64el"
-  CONFIG["target"] = "mips64el-unknown-openbsd6.7"
-  CONFIG["host_os"] = "openbsd6.7"
+  CONFIG["target"] = "mips64el-unknown-openbsd6.9"
+  CONFIG["host_os"] = "openbsd6.9"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "mips64el"
-  CONFIG["host"] = "mips64el-unknown-openbsd6.7"
+  CONFIG["host"] = "mips64el-unknown-openbsd6.9"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd6.7"
+  CONFIG["build_os"] = "openbsd6.9"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "mips64el"
-  CONFIG["build"] = "mips64el-unknown-openbsd6.7"
+  CONFIG["build"] = "mips64el-unknown-openbsd6.9"
   CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
   CONFIG["HAVE_GIT"] = "no"
